commit 141c5d4aa35e6750d45231f0e209a16c5c129d0f
Author: Juergen Spitzmueller <[email protected]>
Date:   Tue Nov 11 09:11:18 2025 +0100

    Properly register local box background (GUI) color (#13248)
---
 src/BufferParams.cpp | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/src/BufferParams.cpp b/src/BufferParams.cpp
index 592feef035..4fa3040511 100644
--- a/src/BufferParams.cpp
+++ b/src/BufferParams.cpp
@@ -1315,9 +1315,10 @@ string BufferParams::readToken(Lexer & lex, string const 
& token,
                        boxbgcolor = lex.getString();
                        if (boxbgcolor == "none")
                                break;
-                       // set a local name for the painter
-                       lcolor.setColor("boxbgcolor@" + filename.absFileName(),
-                                       lcolor.getX11HexName(boxbgcolor));
+                       // Register and set a local name for the painter
+                       string const localcolor = "boxbgcolor@" + 
filename.absFileName();
+                       registerLyXColor(localcolor, boxbgcolor);
+                       lcolor.setColor(localcolor, 
lcolor.getX11HexName(boxbgcolor));
                        break;
                }
                if (token == "\\table_border_color") {
-- 
lyx-cvs mailing list
[email protected]
https://lists.lyx.org/mailman/listinfo/lyx-cvs

Reply via email to